@@ -20,6 +20,9 @@ def transform(file):
     line = None
     while True:
         if line is not None:
-            file.write(line)
-            file.flush()
+            try:
+                file.write(line)
+                file.flush()
+            except BrokenPipeError:
+                return
         line = yield line
